[![Pypi-v](https://img.shields.io/pypi/v/tc_mailmanager.svg)](https://pypi.python.org/pypi/tc_mailmanager)
[![Pypi-pyversions](https://img.shields.io/pypi/pyversions/tc_mailmanager.svg)](https://pypi.python.org/pypi/tc_mailmanager)
[![Pypi-l](https://img.shields.io/pypi/l/tc_mailmanager.svg)](https://pypi.python.org/pypi/tc_mailmanager)
[![Pypi-wheel](https://img.shields.io/pypi/wheel/tc_mailmanager.svg)](https://pypi.python.org/pypi/tc_mailmanager)
[![GitHub Actions](https://github.com/ToucanToco/tc_mailmanager/workflows/CI/badge.svg)](https://github.com/ToucanToco/tc_mailmanager/actions?query=workflow%3ACI)
[![codecov](https://codecov.io/gh/ToucanToco/tc_mailmanager/branch/main/graph/badge.svg)](https://codecov.io/gh/ToucanToco/tc_mailmanager)

# tc_mailmanager

ToucanToco's cross-python-projects MailManager

## Installation

```bash
$ pip install tc_mailmanager
```

# Development

You need to install [poetry](https://python-poetry.org/) either globally or in a virtualenv.
Then run `make install`
